@@ -13,12 +13,13 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from glanceclient.common import http
-from glanceclient.v1 import images
-from glanceclient.v1 import image_members
+from glanceclient.common.http import HTTPClient
+from glanceclient.common import utils
+from glanceclient.v1.image_members import ImageMemberManager
+from glanceclient.v1.images import ImageManager
 
 
-class Client(http.HTTPClient):
+class Client(object):
     """Client for the OpenStack Images v1 API.
 
     :param string endpoint: A user-supplied endpoint URL for the glance
@@ -28,8 +29,9 @@ class Client(http.HTTPClient):
                             http requests. (optional)
     """
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, endpoint, *args, **kwargs):
         """Initialize a new client for the Images v1 API."""
-        super(Client, self).__init__(*args, **kwargs)
-        self.images = images.ImageManager(self)
-        self.image_members = image_members.ImageMemberManager(self)
+        self.http_client = HTTPClient(utils.strip_version(endpoint),
+                                      *args, **kwargs)
+        self.images = ImageManager(self.http_client)
+        self.image_members = ImageMemberManager(self.http_client)
